@@ -1,12 +1,13 @@
-from __future__ import absolute_import
 import logging
 import glob
 import os
 
 from oslo.config import cfg
 
+from seedbox import constants
+from seedbox import db
 from seedbox.common import tools
-from seedbox.db import api as dbapi
+from seedbox.db import models
 from seedbox.torrent import parser
 
 LOG = logging.getLogger(__name__)
@@ -19,6 +20,8 @@ def load_torrents():
     a record in the cache for each torrent.
     """
 
+    dbapi = db.dbapi()
+
     for torrent_file in glob.glob(os.path.join(cfg.CONF.torrent.torrent_path,
                                                '*.torrent')):
 
@@ -31,20 +34,23 @@ def load_torrents():
             try:
                 torparser = parser.TorrentParser(torrent_file)
                 media_items = torparser.get_files_details()
-                LOG.trace('Total files in torrent %d', len(media_items))
+                LOG.debug('Total files in torrent %d', len(media_items))
 
                 # determine if any of the files are still inprogress of
                 # being downloaded; if so then go to next torrent.
                 # Because no files were added to the cache for the torrent
                 # we will once again parse and attempt to process it.
                 if _is_torrent_downloading(media_items):
-                    LOG.trace('torrent still downloading, next...')
+                    LOG.debug('torrent still downloading, next...')
                     continue
 
-                dbapi.add_files_to_torrent(torrent,
-                                           _filter_media(media_items))
+                dbapi.bulk_create_medias(
+                    _filter_media(torrent.torrent_id, media_items))
+
             except parser.ParsingError as ape:
-                dbapi.set_invalid(torrent)
+                torrent.invalid = True
+                torrent.state = constants.CANCELLED
+                dbapi.save_torrent(torrent)
                 LOG.error('Torrent Parsing Error: [%s] [%s]',
                           torrent_file, ape)
 
@@ -61,18 +67,18 @@ def _is_parsing_required(torrent):
 
     # if we have parse the file previous and marked it invalid, then no
     # need to bother doing it again
-    if torrent.invalid is True:
+    if torrent.invalid:
         parse = False
 
     # if we have already purged the torrent media files, then no need
     # to perform any parsing again
-    if torrent.purged is True:
+    if torrent.purged:
         parse = False
 
     # we have already parsed the file previously, which is why there are
     # files already associated to the torrent, otherwise it would have
     # been zero
-    if torrent.media_files.count() > 0:
+    if torrent.media_files:
         parse = False
 
     return parse
@@ -103,7 +109,7 @@ def _is_torrent_downloading(media_items):
     return found
 
 
-def _filter_media(media_items):
+def _filter_media(torrent_id, media_items):
     """
     Handles interacting with torrent parser and getting required details
     from the parser.
@@ -121,67 +127,64 @@ def _filter_media(media_items):
 
     file_list = []
     for (filename, filesize) in media_items:
-        if filename:
 
-            details = {}
-            details['filename'] = filename
-            details['size'] = filesize
+        media = models.MediaFile.make_empty()
+        media.torrent_id = torrent_id
+        media.filename = filename
+        media.size = filesize
 
-            in_ext = os.path.splitext(filename)[1]
-            details['file_ext'] = in_ext
+        in_ext = os.path.splitext(filename)[1]
+        media.file_ext = in_ext
 
-            # default to missing; no need to check all the paths for a file
-            # if we don't really care about the file to start with, ie a file
-            # we plan to skip
-            details['file_path'] = None
+        # default to missing; no need to check all the paths for a file
+        # if we don't really care about the file to start with, ie a file
+        # we plan to skip
+        media.file_path = None
 
-            # we will assume each file is not synced
-            # desired (not skipped), and accessible
-            details['compressed'] = 0
-            details['synced'] = 0
-            details['skipped'] = 0
-            details['missing'] = 0
+        # we will assume each file is not synced
+        # desired (not skipped), and accessible
+        media.compressed = False
+        media.synced = False
+        media.skipped = False
+        media.missing = False
 
-            # if ends with rar, then it is a compressed file;
-            if in_ext in compressed_types:
-                details['compressed'] = 1
-                LOG.debug('adding compressed file: %s', filename)
+        # if ends with rar, then it is a compressed file;
+        if in_ext in compressed_types:
+            media.compressed = True
+            LOG.debug('adding compressed file: %s', filename)
 
-            # if the file is a video type, but less than 75Mb then
-            # the file is just a sample video and as such we will
-            # skip the file
-            elif in_ext in video_types:
-                if filesize < min_file_size:
-                    details['skipped'] = 1
-                    LOG.debug(
-                        'Based on size, this is a sample file [%s].\
-                         Skipping..', filename)
-                else:
-                    LOG.debug('adding video file: %s', filename)
-
-            # if the file has any other extension (rNN, etc.) we will
-            # simply skip the file
-            else:
-                details['skipped'] = 1
+        # if the file is a video type, but less than 75Mb then
+        # the file is just a sample video and as such we will
+        # skip the file
+        elif in_ext in video_types:
+            if filesize < min_file_size:
+                media.skipped = True
                 LOG.debug(
-                    'Unsupported filetype (%s); skipping file', in_ext)
-
-            # now that we know if the file should be skipped or not from above
-            # we will determine if the file is truly available based on the
-            # full path and filename. If file is not found, then we will set
-            # the file to missing
-            if not details.get('skipped'):
-                details['file_path'] = _get_file_path(filename)
-                if not details['file_path']:
-                    details['missing'] = 1
-                    LOG.info('Media file [%s] not found', filename)
-
-            # now we can add the file to the torrent
-            file_list.append(details)
-            LOG.trace('Added file to torrent with details: [%s]', details)
+                    'Based on size, this is a sample file [%s].\
+                     Skipping..', filename)
+            else:
+                LOG.debug('adding video file: %s', filename)
 
+        # if the file has any other extension (rNN, etc.) we will
+        # simply skip the file
         else:
-            LOG.warn('No indexed files found in torrent.')
+            LOG.debug(
+                'Unsupported filetype (%s); skipping file', in_ext)
+            continue
+
+        # now that we know if the file should be skipped or not from above
+        # we will determine if the file is truly available based on the
+        # full path and filename. If file is not found, then we will set
+        # the file to missing
+        if not media.skipped:
+            media.file_path = _get_file_path(filename)
+            if not media.file_path:
+                media.missing = True
+                LOG.info('Media file [%s] not found', filename)
+
+        # now we can add the file to the torrent
+        file_list.append(media)
+        LOG.debug('Added file to torrent with details: [%s]', media)
 
     return file_list
 
